@@ -2,17 +2,15 @@
 """
     MoinMoin - ImprovedTableParser library
 
-    @copyright: 2012 by Paul Boddie <paul@boddie.org.uk>
-    @copyright: 2008 MoinMoin:FlorianKrupicka (redirectedOutput code)
+    @copyright: 2012, 2013, 2015 by Paul Boddie <paul@boddie.org.uk>
     @license: GNU GPL (v2 or later), see COPYING.txt for details.
 """
 
 from MoinMoin import wikiutil
-from StringIO import StringIO
 from MoinSupport import *
 import re
 
-__version__ = "0.2"
+__version__ = "0.2.1"
 
 # Regular expressions.
 
@@ -97,7 +95,10 @@ def parse(s):
                         column_usage = []
 
                         for column_attrs, text in columns:
-                            rowspan = int(strip_token(column_attrs.get("rowspan", "1")))
+                            try:
+                                rowspan = int(column_attrs.get("rowspan", "1"))
+                            except ValueError:
+                                rowspan = 1
                             if rowspan > 1:
                                 attrs = {}
                                 attrs.update(column_attrs)
@@ -143,7 +144,7 @@ def parse(s):
                         match = patterns["column"].search(text)
                         if match:
                             attribute_text, text = match.groups()
-                            column_attrs = parseAttributes(attribute_text, True)
+                            column_attrs = parseAttributes(attribute_text, False)
                         else:
                             column_attrs = {}
 
@@ -232,7 +233,10 @@ def span_columns(columns, columnnumber):
     # Handle any previous column spanning other columns.
 
     if column_attrs.has_key("colspan"):
-        colspan = int(strip_token(column_attrs["colspan"]))
+        try:
+            colspan = int(column_attrs["colspan"])
+        except ValueError:
+            colspan = 1
 
         # Duplicate the current column as continuation
         # columns for as long as the colspan is defined.
